@@ -69,7 +69,7 @@ class SpendSim:
         self.mempool_manager = MempoolManager(coin_store, defaults)
         self.block_records = []
         self.blocks = []
-        self.timestamp = defaults.INITIAL_FREEZE_END_TIMESTAMP + 1
+        self.timestamp = 1
         self.block_height = 0
         self.defaults = defaults
         return self
@@ -129,8 +129,9 @@ class SpendSim:
             uint64(calculate_base_farmer_reward(next_block_height) + fees),
             self.defaults.GENESIS_CHALLENGE,
         )
-        await self.mempool_manager.coin_store._add_coin_record(self.new_coin_record(pool_coin, True), False)
-        await self.mempool_manager.coin_store._add_coin_record(self.new_coin_record(farmer_coin, True), False)
+        await self.mempool_manager.coin_store._add_coin_records(
+            [self.new_coin_record(pool_coin, True), self.new_coin_record(farmer_coin, True)]
+        )
 
         # Coin store gets updated
         generator_bundle: Optional[SpendBundle] = None
@@ -147,10 +148,12 @@ class SpendSim:
                     return_additions = additions
                     return_removals = removals
 
-                for addition in additions:
-                    await self.mempool_manager.coin_store._add_coin_record(self.new_coin_record(addition), False)
-                for removal in removals:
-                    await self.mempool_manager.coin_store._set_spent(removal.name(), uint32(self.block_height + 1))
+                await self.mempool_manager.coin_store._add_coin_records(
+                    [self.new_coin_record(addition) for addition in additions]
+                )
+                await self.mempool_manager.coin_store._set_spent(
+                    [r.name() for r in removals], uint32(self.block_height + 1)
+                )
 
         # SimBlockRecord is created
         generator: Optional[BlockGenerator] = await self.generate_transaction_generator(generator_bundle)
@@ -192,7 +195,7 @@ class SpendSim:
         if new_br_list:
             self.timestamp = new_br_list[-1].timestamp
         else:
-            self.timestamp = uint64(self.defaults.INITIAL_FREEZE_END_TIMESTAMP + 1)
+            self.timestamp = uint64(1)
 
 
 class SimClient:
@@ -200,7 +203,9 @@ class SimClient:
         self.service = service
 
     async def push_tx(self, spend_bundle: SpendBundle) -> Tuple[MempoolInclusionStatus, Optional[Err]]:
-        cost_result: NPCResult = await self.service.mempool_manager.pre_validate_spendbundle(spend_bundle)
+        cost_result: NPCResult = await self.service.mempool_manager.pre_validate_spendbundle(
+            spend_bundle, spend_bundle.name()
+        )
         cost, status, error = await self.service.mempool_manager.add_spendbundle(
             spend_bundle, cost_result, spend_bundle.name()
         )
