@@ -346,6 +346,9 @@ class WebSocketServer:
         user_passphrase_is_set: bool = Keychain.has_master_passphrase() and not using_default_passphrase()
         locked: bool = Keychain.is_keyring_locked()
         needs_migration: bool = Keychain.needs_migration()
+        can_remove_legacy_keys: bool = False  # Disabling GUI support for removing legacy keys post-migration
+        can_set_passphrase_hint: bool = True
+        passphrase_hint: str = Keychain.get_master_passphrase_hint() or ""
         requirements: Dict[str, Any] = passphrase_requirements()
         response: Dict[str, Any] = {
             "success": True,
@@ -354,6 +357,9 @@ class WebSocketServer:
             "can_save_passphrase": can_save_passphrase,
             "user_passphrase_is_set": user_passphrase_is_set,
             "needs_migration": needs_migration,
+            "can_remove_legacy_keys": can_remove_legacy_keys,
+            "can_set_passphrase_hint": can_set_passphrase_hint,
+            "passphrase_hint": passphrase_hint,
             "passphrase_requirements": requirements,
         }
         return response
@@ -421,11 +427,16 @@ class WebSocketServer:
         success: bool = False
         error: Optional[str] = None
         passphrase: Optional[str] = request.get("passphrase", None)
+        passphrase_hint: Optional[str] = request.get("passphrase_hint", None)
+        save_passphrase: bool = request.get("save_passphrase", False)
         cleanup_legacy_keyring: bool = request.get("cleanup_legacy_keyring", False)
 
         if passphrase is not None and type(passphrase) is not str:
             return {"success": False, "error": 'expected string value for "passphrase"'}
 
+        if passphrase_hint is not None and type(passphrase_hint) is not str:
+            return {"success": False, "error": 'expected string value for "passphrase_hint"'}
+
         if not Keychain.passphrase_meets_requirements(passphrase):
             return {"success": False, "error": "passphrase doesn't satisfy requirements"}
 
@@ -433,7 +444,12 @@ class WebSocketServer:
             return {"success": False, "error": 'expected bool value for "cleanup_legacy_keyring"'}
 
         try:
-            Keychain.migrate_legacy_keyring(passphrase=passphrase, cleanup_legacy_keyring=cleanup_legacy_keyring)
+            Keychain.migrate_legacy_keyring(
+                passphrase=passphrase,
+                passphrase_hint=passphrase_hint,
+                save_passphrase=save_passphrase,
+                cleanup_legacy_keyring=cleanup_legacy_keyring,
+            )
             success = True
             # Inform the GUI of keyring status changes
             self.keyring_status_changed(await self.keyring_status(), "wallet_ui")
@@ -450,6 +466,8 @@ class WebSocketServer:
         error: Optional[str] = None
         current_passphrase: Optional[str] = None
         new_passphrase: Optional[str] = None
+        passphrase_hint: Optional[str] = request.get("passphrase_hint", None)
+        save_passphrase: bool = request.get("save_passphrase", False)
 
         if using_default_passphrase():
             current_passphrase = default_passphrase()
@@ -468,7 +486,13 @@ class WebSocketServer:
 
         try:
             assert new_passphrase is not None  # mypy, I love you
-            Keychain.set_master_passphrase(current_passphrase, new_passphrase, allow_migration=False)
+            Keychain.set_master_passphrase(
+                current_passphrase,
+                new_passphrase,
+                allow_migration=False,
+                passphrase_hint=passphrase_hint,
+                save_passphrase=save_passphrase,
+            )
         except KeyringRequiresMigration:
             error = "keyring requires migration"
         except KeyringCurrentPassphraseIsInvalid:
@@ -782,7 +806,7 @@ class WebSocketServer:
             self.state_changed(service_plotter, self.prepare_plot_state_message(PlotEvent.STATE_CHANGED, id))
 
         except (subprocess.SubprocessError, IOError):
-            log.exception(f"problem starting {service_name}")
+            log.exception(f"problem starting {service_name}")  # lgtm [py/clear-text-logging-sensitive-data]
             error = Exception("Start plotting failed")
             config["state"] = PlotState.FINISHED
             config["error"] = error
@@ -1052,7 +1076,7 @@ def launch_plotter(root_path: Path, service_name: str, service_array: List[str],
     else:
         mkdir(plotter_path.parent)
     outfile = open(plotter_path.resolve(), "w")
-    log.info(f"Service array: {service_array}")
+    log.info(f"Service array: {service_array}")  # lgtm [py/clear-text-logging-sensitive-data]
     process = subprocess.Popen(
         service_array,
         shell=False,
