@@ -11,6 +11,7 @@ from chia.plotting.manager import PlotManager
 from chia.plotting.util import (
     PlotRefreshResult,
     PlotsRefreshParameter,
+    PlotRefreshEvents,
     get_plot_filenames,
     find_duplicate_plot_IDs,
     parse_plot_info,
@@ -23,8 +24,8 @@ from chia.wallet.derive_keys import master_sk_to_farmer_sk, master_sk_to_local_s
 log = logging.getLogger(__name__)
 
 
-def plot_refresh_callback(refresh_result: PlotRefreshResult):
-    log.info(f"loaded {refresh_result.loaded_plots} plots, {refresh_result.remaining_files} remaining")
+def plot_refresh_callback(event: PlotRefreshEvents, refresh_result: PlotRefreshResult):
+    log.info(f"event: {event.name}, loaded {refresh_result.loaded} plots, {refresh_result.remaining} remaining")
 
 
 def check_plots(root_path, num, challenge_start, grep_string, list_duplicates, debug_show_memo):
@@ -94,7 +95,6 @@ def check_plots(root_path, num, challenge_start, grep_string, list_duplicates, d
         log.info("")
         log.info(f"Starting to test each plot with {num} challenges each\n")
     total_good_plots: Counter = Counter()
-    total_bad_plots = 0
     total_size = 0
     bad_plots_list: List[Path] = []
 
@@ -165,7 +165,6 @@ def check_plots(root_path, num, challenge_start, grep_string, list_duplicates, d
                 total_good_plots[pr.get_size()] += 1
                 total_size += plot_path.stat().st_size
             else:
-                total_bad_plots += 1
                 log.error(f"\tProofs {total_proofs} / {challenges}, {round(total_proofs/float(challenges), 4)}")
                 bad_plots_list.append(plot_path)
     log.info("")
@@ -175,11 +174,17 @@ def check_plots(root_path, num, challenge_start, grep_string, list_duplicates, d
     log.info(f"Found {total_plots} valid plots, total size {total_size / (1024 * 1024 * 1024 * 1024):.5f} TiB")
     for (k, count) in sorted(dict(total_good_plots).items()):
         log.info(f"{count} plots of size {k}")
-    grand_total_bad = total_bad_plots + len(plot_manager.failed_to_open_filenames)
+    grand_total_bad = len(bad_plots_list) + len(plot_manager.failed_to_open_filenames)
     if grand_total_bad > 0:
         log.warning(f"{grand_total_bad} invalid plots found:")
-        for bad_plot_path in bad_plots_list:
-            log.warning(f"{bad_plot_path}")
+        if len(bad_plots_list) > 0:
+            log.warning(f"    {len(bad_plots_list)} bad plots:")
+            for bad_plot_path in bad_plots_list:
+                log.warning(f"{bad_plot_path}")
+        if len(plot_manager.failed_to_open_filenames) > 0:
+            log.warning(f"    {len(plot_manager.failed_to_open_filenames)} unopenable plots:")
+            for unopenable_plot_path in plot_manager.failed_to_open_filenames.keys():
+                log.warning(f"{unopenable_plot_path}")
     if len(plot_manager.no_key_filenames) > 0:
         log.warning(
             f"There are {len(plot_manager.no_key_filenames)} plots with a farmer or pool public key that "
