@@ -1,5 +1,5 @@
 import io
-from typing import List, Set, Tuple
+from typing import List, Set, Tuple, Optional, Any
 
 from clvm import KEYWORD_FROM_ATOM, KEYWORD_TO_ATOM, SExp
 from clvm import run_program as default_run_program
@@ -7,11 +7,12 @@ from clvm.casts import int_from_bytes
 from clvm.EvalError import EvalError
 from clvm.operators import OP_REWRITE, OPERATOR_LOOKUP
 from clvm.serialize import sexp_from_stream, sexp_to_stream
-from clvm_rs import STRICT_MODE, deserialize_and_run_program2, serialized_length
+from clvm_rs import STRICT_MODE, deserialize_and_run_program2, serialized_length, run_generator
 from clvm_tools.curry import curry, uncurry
 
 from chia.types.blockchain_format.sized_bytes import bytes32
 from chia.util.hash import std_hash
+from chia.util.byte_types import hexstr_to_bytes
 
 from .tree_hash import sha256_treehash
 
@@ -54,9 +55,17 @@ class Program(SExp):
         assert f.read() == b""
         return result
 
+    @classmethod
+    def fromhex(cls, hexstr: str) -> "Program":
+        return cls.from_bytes(hexstr_to_bytes(hexstr))
+
     def to_serialized_program(self) -> "SerializedProgram":
         return SerializedProgram.from_bytes(bytes(self))
 
+    @classmethod
+    def from_serialized_program(cls, sp: "SerializedProgram") -> "Program":
+        return cls.from_bytes(bytes(sp))
+
     def __bytes__(self) -> bytes:
         f = io.BytesIO()
         self.stream(f)  # type: ignore # noqa
@@ -65,6 +74,25 @@ class Program(SExp):
     def __str__(self) -> str:
         return bytes(self).hex()
 
+    def at(self, position: str) -> "Program":
+        """
+        Take a string of only `f` and `r` characters and follow the corresponding path.
+
+        Example:
+
+        `assert Program.to(17) == Program.to([10, 20, 30, [15, 17], 40, 50]).at("rrrfrf")`
+
+        """
+        v = self
+        for c in position.lower():
+            if c == "f":
+                v = v.first()
+            elif c == "r":
+                v = v.rest()
+            else:
+                raise ValueError(f"`at` got illegal character `{c}`. Only `f` & `r` allowed")
+        return v
+
     def get_tree_hash(self, *args: List[bytes32]) -> bytes32:
         """
         Any values in `args` that appear in the tree
@@ -166,6 +194,10 @@ class SerializedProgram:
         ret._buf = bytes(blob)
         return ret
 
+    @classmethod
+    def fromhex(cls, hexstr: str) -> "SerializedProgram":
+        return cls.from_bytes(hexstr_to_bytes(hexstr))
+
     @classmethod
     def from_program(cls, p: Program) -> "SerializedProgram":
         ret = SerializedProgram()
@@ -211,6 +243,31 @@ class SerializedProgram:
     def run_with_cost(self, max_cost: int, *args) -> Tuple[int, Program]:
         return self._run(max_cost, 0, *args)
 
+    def run_as_generator(self, max_cost: int, flags: int, *args) -> Tuple[Optional[int], List[Any], int]:
+        serialized_args = b""
+        if len(args) > 1:
+            # when we have more than one argument, serialize them into a list
+            for a in args:
+                serialized_args += b"\xff"
+                serialized_args += _serialize(a)
+            serialized_args += b"\x80"
+        else:
+            serialized_args += _serialize(args[0])
+
+        native_opcode_names_by_opcode = dict(
+            ("op_%s" % OP_REWRITE.get(k, k), op) for op, k in KEYWORD_FROM_ATOM.items() if k not in "qa."
+        )
+        err, npc_list, cost = run_generator(
+            self._buf,
+            serialized_args,
+            KEYWORD_TO_ATOM["q"][0],
+            KEYWORD_TO_ATOM["a"][0],
+            native_opcode_names_by_opcode,
+            max_cost,
+            flags,
+        )
+        return None if err == 0 else err, npc_list, cost
+
     def _run(self, max_cost: int, flags, *args) -> Tuple[int, Program]:
         # when multiple arguments are passed, concatenate them into a serialized
         # buffer. Some arguments may already be in serialized form (e.g.
