@@ -1,8 +1,9 @@
 import asyncio
+import logging
 from typing import Optional
 
 
-def cancel_task_safe(task: Optional[asyncio.Task], log=None):
+def cancel_task_safe(task: Optional[asyncio.Task], log: Optional[logging.Logger] = None):
     if task is not None:
         try:
             task.cancel()
