@@ -134,7 +134,7 @@ class TestBlockchainTransactions:
         )
 
         next_block = new_blocks[-1]
-        res, err, _ = await full_node_1.blockchain.receive_block(next_block)
+        res, err, _, _ = await full_node_1.blockchain.receive_block(next_block)
         assert res == ReceiveBlockResult.INVALID_BLOCK
         assert err == Err.DOUBLE_SPEND
 
@@ -174,7 +174,7 @@ class TestBlockchainTransactions:
         )
 
         next_block = new_blocks[-1]
-        res, err, _ = await full_node_1.blockchain.receive_block(next_block)
+        res, err, _, _ = await full_node_1.blockchain.receive_block(next_block)
         assert res == ReceiveBlockResult.INVALID_BLOCK
         assert err == Err.DUPLICATE_OUTPUT
 
@@ -233,7 +233,7 @@ class TestBlockchainTransactions:
             transaction_data=spend_bundle,
         )
 
-        res, err, _ = await full_node_api_1.full_node.blockchain.receive_block(new_blocks[-1])
+        res, err, _, _ = await full_node_api_1.full_node.blockchain.receive_block(new_blocks[-1])
         assert err is None
         assert res == ReceiveBlockResult.NEW_PEAK
 
@@ -246,7 +246,7 @@ class TestBlockchainTransactions:
             transaction_data=spend_bundle,
         )
 
-        res, err, _ = await full_node_api_1.full_node.blockchain.receive_block(new_blocks_double[-1])
+        res, err, _, _ = await full_node_api_1.full_node.blockchain.receive_block(new_blocks_double[-1])
         assert err is Err.DOUBLE_SPEND
         assert res == ReceiveBlockResult.INVALID_BLOCK
 
@@ -288,8 +288,7 @@ class TestBlockchainTransactions:
                 await full_node_api_1.full_node.respond_block(full_node_protocol.RespondBlock(block))
 
     @pytest.mark.asyncio
-    @pytest.mark.parametrize("rust_checker", [True, False])
-    async def test_validate_blockchain_spend_reorg_coin(self, two_nodes, rust_checker: bool):
+    async def test_validate_blockchain_spend_reorg_coin(self, two_nodes):
         num_blocks = 10
         wallet_a = WALLET_A
         coinbase_puzzlehash = WALLET_A_PUZZLE_HASHES[0]
@@ -328,7 +327,7 @@ class TestBlockchainTransactions:
 
         coin_2 = None
         for coin in run_and_get_removals_and_additions(
-            new_blocks[-1], test_constants.MAX_BLOCK_COST_CLVM, test_constants.COST_PER_BYTE, rust_checker=rust_checker
+            new_blocks[-1], test_constants.MAX_BLOCK_COST_CLVM, test_constants.COST_PER_BYTE
         )[1]:
             if coin.puzzle_hash == receiver_1_puzzlehash:
                 coin_2 = coin
@@ -349,7 +348,7 @@ class TestBlockchainTransactions:
 
         coin_3 = None
         for coin in run_and_get_removals_and_additions(
-            new_blocks[-1], test_constants.MAX_BLOCK_COST_CLVM, test_constants.COST_PER_BYTE, rust_checker=rust_checker
+            new_blocks[-1], test_constants.MAX_BLOCK_COST_CLVM, test_constants.COST_PER_BYTE
         )[1]:
             if coin.puzzle_hash == receiver_2_puzzlehash:
                 coin_3 = coin
@@ -513,7 +512,7 @@ class TestBlockchainTransactions:
         )
 
         # Try to validate that block
-        res, err, _ = await full_node_1.blockchain.receive_block(invalid_new_blocks[-1])
+        res, err, _, _ = await full_node_1.blockchain.receive_block(invalid_new_blocks[-1])
         assert res == ReceiveBlockResult.INVALID_BLOCK
         assert err == Err.ASSERT_MY_COIN_ID_FAILED
 
@@ -526,7 +525,7 @@ class TestBlockchainTransactions:
             transaction_data=valid_spend_bundle,
             guarantee_transaction_block=True,
         )
-        res, err, _ = await full_node_1.blockchain.receive_block(new_blocks[-1])
+        res, err, _, _ = await full_node_1.blockchain.receive_block(new_blocks[-1])
         assert res == ReceiveBlockResult.NEW_PEAK
         assert err is None
 
@@ -593,7 +592,7 @@ class TestBlockchainTransactions:
         )
 
         # Try to validate that block
-        res, err, _ = await full_node_1.blockchain.receive_block(invalid_new_blocks[-1])
+        res, err, _, _ = await full_node_1.blockchain.receive_block(invalid_new_blocks[-1])
         assert res == ReceiveBlockResult.INVALID_BLOCK
         assert err == Err.ASSERT_ANNOUNCE_CONSUMED_FAILED
 
@@ -610,7 +609,7 @@ class TestBlockchainTransactions:
         )
 
         # Try to validate newly created block
-        res, err, _ = await full_node_1.blockchain.receive_block(new_blocks[-1])
+        res, err, _, _ = await full_node_1.blockchain.receive_block(new_blocks[-1])
         assert res == ReceiveBlockResult.NEW_PEAK
         assert err is None
 
@@ -677,7 +676,7 @@ class TestBlockchainTransactions:
         )
 
         # Try to validate that block
-        res, err, _ = await full_node_1.blockchain.receive_block(invalid_new_blocks[-1])
+        res, err, _, _ = await full_node_1.blockchain.receive_block(invalid_new_blocks[-1])
         assert res == ReceiveBlockResult.INVALID_BLOCK
         assert err == Err.ASSERT_ANNOUNCE_CONSUMED_FAILED
 
@@ -694,7 +693,7 @@ class TestBlockchainTransactions:
         )
 
         # Try to validate newly created block
-        res, err, _ = await full_node_1.blockchain.receive_block(new_blocks[-1])
+        res, err, _, _ = await full_node_1.blockchain.receive_block(new_blocks[-1])
         assert res == ReceiveBlockResult.NEW_PEAK
         assert err is None
 
@@ -740,7 +739,7 @@ class TestBlockchainTransactions:
         )
 
         # Try to validate that block at index 10
-        res, err, _ = await full_node_1.blockchain.receive_block(invalid_new_blocks[-1])
+        res, err, _, _ = await full_node_1.blockchain.receive_block(invalid_new_blocks[-1])
         assert res == ReceiveBlockResult.INVALID_BLOCK
         assert err == Err.ASSERT_HEIGHT_ABSOLUTE_FAILED
 
@@ -750,7 +749,7 @@ class TestBlockchainTransactions:
             farmer_reward_puzzle_hash=coinbase_puzzlehash,
             guarantee_transaction_block=True,
         )
-        res, _, _ = await full_node_1.blockchain.receive_block(new_blocks[-1])
+        res, _, _, _ = await full_node_1.blockchain.receive_block(new_blocks[-1])
         assert res == ReceiveBlockResult.NEW_PEAK
 
         # At index 11, it can be spent
@@ -761,7 +760,7 @@ class TestBlockchainTransactions:
             transaction_data=block1_spend_bundle,
             guarantee_transaction_block=True,
         )
-        res, err, _ = await full_node_1.blockchain.receive_block(new_blocks[-1])
+        res, err, _, _ = await full_node_1.blockchain.receive_block(new_blocks[-1])
         assert err is None
         assert res == ReceiveBlockResult.NEW_PEAK
 
@@ -809,7 +808,7 @@ class TestBlockchainTransactions:
         )
 
         # Try to validate that block at index 11
-        res, err, _ = await full_node_1.blockchain.receive_block(invalid_new_blocks[-1])
+        res, err, _, _ = await full_node_1.blockchain.receive_block(invalid_new_blocks[-1])
         assert res == ReceiveBlockResult.INVALID_BLOCK
         assert err == Err.ASSERT_HEIGHT_RELATIVE_FAILED
 
@@ -819,7 +818,7 @@ class TestBlockchainTransactions:
             farmer_reward_puzzle_hash=coinbase_puzzlehash,
             guarantee_transaction_block=True,
         )
-        res, _, _ = await full_node_1.blockchain.receive_block(new_blocks[-1])
+        res, _, _, _ = await full_node_1.blockchain.receive_block(new_blocks[-1])
         assert res == ReceiveBlockResult.NEW_PEAK
 
         # At index 12, it can be spent
@@ -830,7 +829,7 @@ class TestBlockchainTransactions:
             transaction_data=block1_spend_bundle,
             guarantee_transaction_block=True,
         )
-        res, err, _ = await full_node_1.blockchain.receive_block(new_blocks[-1])
+        res, err, _, _ = await full_node_1.blockchain.receive_block(new_blocks[-1])
         assert err is None
         assert res == ReceiveBlockResult.NEW_PEAK
 
@@ -878,7 +877,7 @@ class TestBlockchainTransactions:
         )
 
         # Try to validate that block before 300 sec
-        res, err, _ = await full_node_1.blockchain.receive_block(invalid_new_blocks[-1])
+        res, err, _, _ = await full_node_1.blockchain.receive_block(invalid_new_blocks[-1])
         assert res == ReceiveBlockResult.INVALID_BLOCK
         assert err == Err.ASSERT_SECONDS_RELATIVE_FAILED
 
@@ -890,7 +889,7 @@ class TestBlockchainTransactions:
             guarantee_transaction_block=True,
             time_per_block=301,
         )
-        res, err, _ = await full_node_1.blockchain.receive_block(valid_new_blocks[-1])
+        res, err, _, _ = await full_node_1.blockchain.receive_block(valid_new_blocks[-1])
         assert err is None
         assert res == ReceiveBlockResult.NEW_PEAK
 
@@ -939,7 +938,7 @@ class TestBlockchainTransactions:
         )
 
         # Try to validate that block before 30 sec
-        res, err, _ = await full_node_1.blockchain.receive_block(invalid_new_blocks[-1])
+        res, err, _, _ = await full_node_1.blockchain.receive_block(invalid_new_blocks[-1])
         assert res == ReceiveBlockResult.INVALID_BLOCK
         assert err == Err.ASSERT_SECONDS_ABSOLUTE_FAILED
 
@@ -951,7 +950,7 @@ class TestBlockchainTransactions:
             guarantee_transaction_block=True,
             time_per_block=31,
         )
-        res, err, _ = await full_node_1.blockchain.receive_block(valid_new_blocks[-1])
+        res, err, _, _ = await full_node_1.blockchain.receive_block(valid_new_blocks[-1])
         assert err is None
         assert res == ReceiveBlockResult.NEW_PEAK
 
@@ -1001,7 +1000,7 @@ class TestBlockchainTransactions:
             guarantee_transaction_block=True,
         )
 
-        res, err, _ = await full_node_1.blockchain.receive_block(invalid_new_blocks[-1])
+        res, err, _, _ = await full_node_1.blockchain.receive_block(invalid_new_blocks[-1])
         assert res == ReceiveBlockResult.INVALID_BLOCK
         assert err == Err.RESERVE_FEE_CONDITION_FAILED
 
@@ -1012,6 +1011,6 @@ class TestBlockchainTransactions:
             transaction_data=block1_spend_bundle_good,
             guarantee_transaction_block=True,
         )
-        res, err, _ = await full_node_1.blockchain.receive_block(valid_new_blocks[-1])
+        res, err, _, _ = await full_node_1.blockchain.receive_block(valid_new_blocks[-1])
         assert err is None
         assert res == ReceiveBlockResult.NEW_PEAK
