@@ -1,4 +1,5 @@
 import asyncio
+import atexit
 import signal
 
 from secrets import token_bytes
@@ -18,13 +19,22 @@ from chia.simulator.start_simulator import service_kwargs_for_full_node_simulato
 from chia.timelord.timelord_launcher import kill_processes, spawn_process
 from chia.types.peer_info import PeerInfo
 from chia.util.bech32m import encode_puzzle_hash
-from tests.block_tools import BlockTools, test_constants
+from tests.block_tools import create_block_tools, create_block_tools_async, test_constants
+from tests.util.keyring import TempKeyring
 from chia.util.hash import std_hash
 from chia.util.ints import uint16, uint32
-from chia.util.keychain import Keychain, bytes_to_mnemonic
+from chia.util.keychain import bytes_to_mnemonic
 from tests.time_out_assert import time_out_assert_custom_interval
 
-bt = BlockTools(constants=test_constants)
+
+def cleanup_keyring(keyring: TempKeyring):
+    keyring.cleanup()
+
+
+temp_keyring = TempKeyring()
+keychain = temp_keyring.get_keychain()
+atexit.register(cleanup_keyring, temp_keyring)  # Attempt to cleanup the temp keychain
+bt = create_block_tools(constants=test_constants, keychain=keychain)
 
 self_hostname = bt.config["self_hostname"]
 
@@ -121,61 +131,61 @@ async def setup_wallet_node(
     key_seed=None,
     starting_height=None,
 ):
-    config = bt.config["wallet"]
-    config["port"] = port
-    config["rpc_port"] = port + 1000
-    if starting_height is not None:
-        config["starting_height"] = starting_height
-    config["initial_num_public_keys"] = 5
+    with TempKeyring() as keychain:
+        config = bt.config["wallet"]
+        config["port"] = port
+        config["rpc_port"] = port + 1000
+        if starting_height is not None:
+            config["starting_height"] = starting_height
+        config["initial_num_public_keys"] = 5
 
-    entropy = token_bytes(32)
-    keychain = Keychain(entropy.hex(), True)
-    if key_seed is None:
-        key_seed = entropy
-    keychain.add_private_key(bytes_to_mnemonic(key_seed), "")
-    first_pk = keychain.get_first_public_key()
-    assert first_pk is not None
-    db_path_key_suffix = str(first_pk.get_fingerprint())
-    db_name = f"test-wallet-db-{port}-KEY.sqlite"
-    db_path_replaced: str = db_name.replace("KEY", db_path_key_suffix)
-    db_path = bt.root_path / db_path_replaced
+        entropy = token_bytes(32)
+        if key_seed is None:
+            key_seed = entropy
+        keychain.add_private_key(bytes_to_mnemonic(key_seed), "")
+        first_pk = keychain.get_first_public_key()
+        assert first_pk is not None
+        db_path_key_suffix = str(first_pk.get_fingerprint())
+        db_name = f"test-wallet-db-{port}-KEY.sqlite"
+        db_path_replaced: str = db_name.replace("KEY", db_path_key_suffix)
+        db_path = bt.root_path / db_path_replaced
 
-    if db_path.exists():
-        db_path.unlink()
-    config["database_path"] = str(db_name)
-    config["testing"] = True
+        if db_path.exists():
+            db_path.unlink()
+        config["database_path"] = str(db_name)
+        config["testing"] = True
 
-    config["introducer_peer"]["host"] = self_hostname
-    if introducer_port is not None:
-        config["introducer_peer"]["port"] = introducer_port
-        config["peer_connect_interval"] = 10
-    else:
-        config["introducer_peer"] = None
+        config["introducer_peer"]["host"] = self_hostname
+        if introducer_port is not None:
+            config["introducer_peer"]["port"] = introducer_port
+            config["peer_connect_interval"] = 10
+        else:
+            config["introducer_peer"] = None
 
-    if full_node_port is not None:
-        config["full_node_peer"] = {}
-        config["full_node_peer"]["host"] = self_hostname
-        config["full_node_peer"]["port"] = full_node_port
-    else:
-        del config["full_node_peer"]
+        if full_node_port is not None:
+            config["full_node_peer"] = {}
+            config["full_node_peer"]["host"] = self_hostname
+            config["full_node_peer"]["port"] = full_node_port
+        else:
+            del config["full_node_peer"]
 
-    kwargs = service_kwargs_for_wallet(local_bt.root_path, config, consensus_constants, keychain)
-    kwargs.update(
-        parse_cli_args=False,
-        connect_to_daemon=False,
-    )
+        kwargs = service_kwargs_for_wallet(local_bt.root_path, config, consensus_constants, keychain)
+        kwargs.update(
+            parse_cli_args=False,
+            connect_to_daemon=False,
+        )
 
-    service = Service(**kwargs)
+        service = Service(**kwargs)
 
-    await service.start(new_wallet=True)
+        await service.start(new_wallet=True)
 
-    yield service._node, service._node.server
+        yield service._node, service._node.server
 
-    service.stop()
-    await service.wait_closed()
-    if db_path.exists():
-        db_path.unlink()
-    keychain.delete_all_keys()
+        service.stop()
+        await service.wait_closed()
+        if db_path.exists():
+            db_path.unlink()
+        keychain.delete_all_keys()
 
 
 async def setup_harvester(port, farmer_port, consensus_constants: ConsensusConstants, b_tools):
@@ -218,7 +228,9 @@ async def setup_farmer(
     else:
         del config["full_node_peer"]
 
-    kwargs = service_kwargs_for_farmer(b_tools.root_path, config, config_pool, b_tools.keychain, consensus_constants)
+    kwargs = service_kwargs_for_farmer(
+        b_tools.root_path, config, config_pool, consensus_constants, b_tools.local_keychain
+    )
     kwargs.update(
         parse_cli_args=False,
         connect_to_daemon=False,
@@ -313,36 +325,49 @@ async def setup_two_nodes(consensus_constants: ConsensusConstants):
     """
     Setup and teardown of two full nodes, with blockchains and separate DBs.
     """
-    node_iters = [
-        setup_full_node(
-            consensus_constants, "blockchain_test.db", 21234, BlockTools(constants=test_constants), simulator=False
-        ),
-        setup_full_node(
-            consensus_constants, "blockchain_test_2.db", 21235, BlockTools(constants=test_constants), simulator=False
-        ),
-    ]
 
-    fn1 = await node_iters[0].__anext__()
-    fn2 = await node_iters[1].__anext__()
+    with TempKeyring() as keychain1, TempKeyring() as keychain2:
+        node_iters = [
+            setup_full_node(
+                consensus_constants,
+                "blockchain_test.db",
+                21234,
+                await create_block_tools_async(constants=test_constants, keychain=keychain1),
+                simulator=False,
+            ),
+            setup_full_node(
+                consensus_constants,
+                "blockchain_test_2.db",
+                21235,
+                await create_block_tools_async(constants=test_constants, keychain=keychain2),
+                simulator=False,
+            ),
+        ]
 
-    yield fn1, fn2, fn1.full_node.server, fn2.full_node.server
+        fn1 = await node_iters[0].__anext__()
+        fn2 = await node_iters[1].__anext__()
 
-    await _teardown_nodes(node_iters)
+        yield fn1, fn2, fn1.full_node.server, fn2.full_node.server
+
+        await _teardown_nodes(node_iters)
 
 
 async def setup_n_nodes(consensus_constants: ConsensusConstants, n: int):
     """
-    Setup and teardown of two full nodes, with blockchains and separate DBs.
+    Setup and teardown of n full nodes, with blockchains and separate DBs.
     """
     port_start = 21244
     node_iters = []
+    keyrings_to_cleanup = []
     for i in range(n):
+        keyring = TempKeyring()
+        keyrings_to_cleanup.append(keyring)
         node_iters.append(
             setup_full_node(
                 consensus_constants,
                 f"blockchain_test_{i}.db",
                 port_start + i,
-                BlockTools(constants=test_constants),
+                await create_block_tools_async(constants=test_constants, keychain=keyring.get_keychain()),
                 simulator=False,
             )
         )
@@ -354,20 +379,26 @@ async def setup_n_nodes(consensus_constants: ConsensusConstants, n: int):
 
     await _teardown_nodes(node_iters)
 
+    for keyring in keyrings_to_cleanup:
+        keyring.cleanup()
+
 
 async def setup_node_and_wallet(consensus_constants: ConsensusConstants, starting_height=None, key_seed=None):
-    btools = BlockTools(constants=test_constants)
-    node_iters = [
-        setup_full_node(consensus_constants, "blockchain_test.db", 21234, btools, simulator=False),
-        setup_wallet_node(21235, consensus_constants, btools, None, starting_height=starting_height, key_seed=key_seed),
-    ]
+    with TempKeyring() as keychain:
+        btools = await create_block_tools_async(constants=test_constants, keychain=keychain)
+        node_iters = [
+            setup_full_node(consensus_constants, "blockchain_test.db", 21234, btools, simulator=False),
+            setup_wallet_node(
+                21235, consensus_constants, btools, None, starting_height=starting_height, key_seed=key_seed
+            ),
+        ]
 
-    full_node_api = await node_iters[0].__anext__()
-    wallet, s2 = await node_iters[1].__anext__()
+        full_node_api = await node_iters[0].__anext__()
+        wallet, s2 = await node_iters[1].__anext__()
 
-    yield full_node_api, wallet, full_node_api.full_node.server, s2
+        yield full_node_api, wallet, full_node_api.full_node.server, s2
 
-    await _teardown_nodes(node_iters)
+        await _teardown_nodes(node_iters)
 
 
 async def setup_simulators_and_wallets(
@@ -378,46 +409,51 @@ async def setup_simulators_and_wallets(
     key_seed=None,
     starting_port=50000,
 ):
-    simulators: List[FullNodeAPI] = []
-    wallets = []
-    node_iters = []
+    with TempKeyring() as keychain1, TempKeyring() as keychain2:
+        simulators: List[FullNodeAPI] = []
+        wallets = []
+        node_iters = []
 
-    consensus_constants = constants_for_dic(dic)
-    for index in range(0, simulator_count):
-        port = starting_port + index
-        db_name = f"blockchain_test_{port}.db"
-        bt_tools = BlockTools(consensus_constants, const_dict=dic)  # block tools modifies constants
-        sim = setup_full_node(
-            bt_tools.constants,
-            db_name,
-            port,
-            bt_tools,
-            simulator=True,
-        )
-        simulators.append(await sim.__anext__())
-        node_iters.append(sim)
+        consensus_constants = constants_for_dic(dic)
+        for index in range(0, simulator_count):
+            port = starting_port + index
+            db_name = f"blockchain_test_{port}.db"
+            bt_tools = await create_block_tools_async(
+                consensus_constants, const_dict=dic, keychain=keychain1
+            )  # block tools modifies constants
+            sim = setup_full_node(
+                bt_tools.constants,
+                db_name,
+                port,
+                bt_tools,
+                simulator=True,
+            )
+            simulators.append(await sim.__anext__())
+            node_iters.append(sim)
 
-    for index in range(0, wallet_count):
-        if key_seed is None:
-            seed = std_hash(uint32(index))
-        else:
-            seed = key_seed
-        port = starting_port + 5000 + index
-        bt_tools = BlockTools(consensus_constants, const_dict=dic)  # block tools modifies constants
-        wlt = setup_wallet_node(
-            port,
-            bt_tools.constants,
-            bt_tools,
-            None,
-            key_seed=seed,
-            starting_height=starting_height,
-        )
-        wallets.append(await wlt.__anext__())
-        node_iters.append(wlt)
+        for index in range(0, wallet_count):
+            if key_seed is None:
+                seed = std_hash(uint32(index))
+            else:
+                seed = key_seed
+            port = starting_port + 5000 + index
+            bt_tools = await create_block_tools_async(
+                consensus_constants, const_dict=dic, keychain=keychain2
+            )  # block tools modifies constants
+            wlt = setup_wallet_node(
+                port,
+                bt_tools.constants,
+                bt_tools,
+                None,
+                key_seed=seed,
+                starting_height=starting_height,
+            )
+            wallets.append(await wlt.__anext__())
+            node_iters.append(wlt)
 
-    yield simulators, wallets
+        yield simulators, wallets
 
-    await _teardown_nodes(node_iters)
+        await _teardown_nodes(node_iters)
 
 
 async def setup_farmer_harvester(consensus_constants: ConsensusConstants):
@@ -437,54 +473,55 @@ async def setup_farmer_harvester(consensus_constants: ConsensusConstants):
 async def setup_full_system(
     consensus_constants: ConsensusConstants, b_tools=None, b_tools_1=None, connect_to_daemon=False
 ):
-    if b_tools is None:
-        b_tools = BlockTools(constants=test_constants)
-    if b_tools_1 is None:
-        b_tools_1 = BlockTools(constants=test_constants)
-    node_iters = [
-        setup_introducer(21233),
-        setup_harvester(21234, 21235, consensus_constants, b_tools),
-        setup_farmer(21235, consensus_constants, b_tools, uint16(21237)),
-        setup_vdf_clients(8000),
-        setup_timelord(21236, 21237, False, consensus_constants, b_tools),
-        setup_full_node(
-            consensus_constants, "blockchain_test.db", 21237, b_tools, 21233, False, 10, True, connect_to_daemon
-        ),
-        setup_full_node(
-            consensus_constants, "blockchain_test_2.db", 21238, b_tools_1, 21233, False, 10, True, connect_to_daemon
-        ),
-        setup_vdf_client(7999),
-        setup_timelord(21239, 21238, True, consensus_constants, b_tools_1),
-    ]
+    with TempKeyring() as keychain1, TempKeyring() as keychain2:
+        if b_tools is None:
+            b_tools = await create_block_tools_async(constants=test_constants, keychain=keychain1)
+        if b_tools_1 is None:
+            b_tools_1 = await create_block_tools_async(constants=test_constants, keychain=keychain2)
+        node_iters = [
+            setup_introducer(21233),
+            setup_harvester(21234, 21235, consensus_constants, b_tools),
+            setup_farmer(21235, consensus_constants, b_tools, uint16(21237)),
+            setup_vdf_clients(8000),
+            setup_timelord(21236, 21237, False, consensus_constants, b_tools),
+            setup_full_node(
+                consensus_constants, "blockchain_test.db", 21237, b_tools, 21233, False, 10, True, connect_to_daemon
+            ),
+            setup_full_node(
+                consensus_constants, "blockchain_test_2.db", 21238, b_tools_1, 21233, False, 10, True, connect_to_daemon
+            ),
+            setup_vdf_client(7999),
+            setup_timelord(21239, 21238, True, consensus_constants, b_tools_1),
+        ]
 
-    introducer, introducer_server = await node_iters[0].__anext__()
-    harvester, harvester_server = await node_iters[1].__anext__()
-    farmer, farmer_server = await node_iters[2].__anext__()
+        introducer, introducer_server = await node_iters[0].__anext__()
+        harvester, harvester_server = await node_iters[1].__anext__()
+        farmer, farmer_server = await node_iters[2].__anext__()
 
-    async def num_connections():
-        count = len(harvester.server.all_connections.items())
-        return count
+        async def num_connections():
+            count = len(harvester.server.all_connections.items())
+            return count
 
-    await time_out_assert_custom_interval(10, 3, num_connections, 1)
+        await time_out_assert_custom_interval(10, 3, num_connections, 1)
 
-    vdf_clients = await node_iters[3].__anext__()
-    timelord, timelord_server = await node_iters[4].__anext__()
-    node_api_1 = await node_iters[5].__anext__()
-    node_api_2 = await node_iters[6].__anext__()
-    vdf_sanitizer = await node_iters[7].__anext__()
-    sanitizer, sanitizer_server = await node_iters[8].__anext__()
+        vdf_clients = await node_iters[3].__anext__()
+        timelord, timelord_server = await node_iters[4].__anext__()
+        node_api_1 = await node_iters[5].__anext__()
+        node_api_2 = await node_iters[6].__anext__()
+        vdf_sanitizer = await node_iters[7].__anext__()
+        sanitizer, sanitizer_server = await node_iters[8].__anext__()
 
-    yield (
-        node_api_1,
-        node_api_2,
-        harvester,
-        farmer,
-        introducer,
-        timelord,
-        vdf_clients,
-        vdf_sanitizer,
-        sanitizer,
-        node_api_1.full_node.server,
-    )
+        yield (
+            node_api_1,
+            node_api_2,
+            harvester,
+            farmer,
+            introducer,
+            timelord,
+            vdf_clients,
+            vdf_sanitizer,
+            sanitizer,
+            node_api_1.full_node.server,
+        )
 
-    await _teardown_nodes(node_iters)
+        await _teardown_nodes(node_iters)
