@@ -3,7 +3,7 @@ from typing import List
 from blspy import AugSchemeMPL, G2Element, PrivateKey
 
 from chia.types.blockchain_format.sized_bytes import bytes32
-from chia.types.coin_solution import CoinSolution
+from chia.types.coin_spend import CoinSpend
 from chia.util.condition_tools import conditions_by_opcode, conditions_for_solution, pkm_pairs_for_conditions_dict
 from tests.core.make_block_generator import GROUP_ORDER, int_to_public_key
 from tests.block_tools import test_constants
@@ -25,15 +25,15 @@ class KeyTool(dict):
         bls_private_key = PrivateKey.from_bytes(secret_exponent.to_bytes(32, "big"))
         return AugSchemeMPL.sign(bls_private_key, message_hash)
 
-    def signature_for_solution(self, coin_solution: CoinSolution, additional_data: bytes) -> AugSchemeMPL:
+    def signature_for_solution(self, coin_spend: CoinSpend, additional_data: bytes) -> AugSchemeMPL:
         signatures = []
         err, conditions, cost = conditions_for_solution(
-            coin_solution.puzzle_reveal, coin_solution.solution, test_constants.MAX_BLOCK_COST_CLVM
+            coin_spend.puzzle_reveal, coin_spend.solution, test_constants.MAX_BLOCK_COST_CLVM
         )
         assert conditions is not None
         conditions_dict = conditions_by_opcode(conditions)
         for public_key, message_hash in pkm_pairs_for_conditions_dict(
-            conditions_dict, coin_solution.coin.name(), additional_data
+            conditions_dict, coin_spend.coin.name(), additional_data
         ):
             signature = self.sign(bytes(public_key), message_hash)
             signatures.append(signature)
