@@ -8,7 +8,7 @@ from chia.types.blockchain_format.program import Program, SerializedProgram
 from chia.types.announcement import Announcement
 from chia.types.blockchain_format.coin import Coin
 from chia.types.blockchain_format.sized_bytes import bytes32
-from chia.types.coin_solution import CoinSolution as CoinSpend
+from chia.types.coin_spend import CoinSpend
 from chia.types.spend_bundle import SpendBundle
 from chia.util.condition_tools import ConditionOpcode
 from chia.util.ints import uint64
@@ -33,6 +33,7 @@ ANYONE_CAN_SPEND_WITH_PADDING_PUZZLE_HASH = Program.to(binutils.assemble("(a (q
 POOL_REWARD_PREFIX_MAINNET = bytes32.fromhex("ccd5bb71183532bff220ba46c268991a00000000000000000000000000000000")
 
 MAX_BLOCK_COST_CLVM = int(1e18)
+COST_PER_BYTE = int(12000)
 
 
 class PuzzleDB:
@@ -417,9 +418,11 @@ def spend_coin_to_singleton(
     coin_spend = CoinSpend(farmed_coin, ANYONE_CAN_SPEND_PUZZLE, conditions)
     spend_bundle = SpendBundle.aggregate([launcher_spend_bundle, SpendBundle([coin_spend], G2Element())])
 
-    additions, removals = coin_store.update_coin_store_for_spend_bundle(spend_bundle, now, MAX_BLOCK_COST_CLVM)
+    additions, removals = coin_store.update_coin_store_for_spend_bundle(
+        spend_bundle, now, MAX_BLOCK_COST_CLVM, COST_PER_BYTE
+    )
 
-    launcher_coin = launcher_spend_bundle.coin_solutions[0].coin
+    launcher_coin = launcher_spend_bundle.coin_spends[0].coin
 
     assert_coin_spent(coin_store, launcher_coin)
     assert_coin_spent(coin_store, farmed_coin)
@@ -519,7 +522,9 @@ def test_lifecycle_with_coinstore_as_wallet():
         coin_spend = SINGLETON_WALLET.coin_spend_for_conditions(PUZZLE_DB, conditions=singleton_conditions)
         spend_bundle = SpendBundle([coin_spend, p2_singleton_coin_spend], G2Element())
 
-        additions, removals = coin_store.update_coin_store_for_spend_bundle(spend_bundle, now, MAX_BLOCK_COST_CLVM)
+        additions, removals = coin_store.update_coin_store_for_spend_bundle(
+            spend_bundle, now, MAX_BLOCK_COST_CLVM, COST_PER_BYTE
+        )
         now.seconds += 500
         now.height += 1
 
@@ -548,7 +553,9 @@ def test_lifecycle_with_coinstore_as_wallet():
         coin_spend = SINGLETON_WALLET.coin_spend_for_conditions(PUZZLE_DB, conditions=singleton_conditions)
         spend_bundle = SpendBundle([coin_spend, p2_singleton_coin_spend], G2Element())
 
-        additions, removals = coin_store.update_coin_store_for_spend_bundle(spend_bundle, now, MAX_BLOCK_COST_CLVM)
+        additions, removals = coin_store.update_coin_store_for_spend_bundle(
+            spend_bundle, now, MAX_BLOCK_COST_CLVM, COST_PER_BYTE
+        )
         now.seconds += 500
         now.height += 1
 
@@ -599,7 +606,9 @@ def test_lifecycle_with_coinstore_as_wallet():
 
     spend_bundle = SpendBundle([singleton_coin_spend], G2Element())
 
-    additions, removals = coin_store.update_coin_store_for_spend_bundle(spend_bundle, now, MAX_BLOCK_COST_CLVM)
+    additions, removals = coin_store.update_coin_store_for_spend_bundle(
+        spend_bundle, now, MAX_BLOCK_COST_CLVM, COST_PER_BYTE
+    )
 
     assert len(list(coin_store.all_unspent_coins())) == 1
 
@@ -635,7 +644,9 @@ def test_lifecycle_with_coinstore_as_wallet():
         spend_bundle = SpendBundle([coin_spend, p2_singleton_coin_spend], G2Element())
         spend_bundle.debug()
 
-        additions, removals = coin_store.update_coin_store_for_spend_bundle(spend_bundle, now, MAX_BLOCK_COST_CLVM)
+        additions, removals = coin_store.update_coin_store_for_spend_bundle(
+            spend_bundle, now, MAX_BLOCK_COST_CLVM, COST_PER_BYTE
+        )
         now.seconds += 500
         now.height += 1
 
@@ -651,7 +662,9 @@ def test_lifecycle_with_coinstore_as_wallet():
     )
     spend_bundle = SpendBundle([coin_spend], G2Element())
 
-    additions, removals = coin_store.update_coin_store_for_spend_bundle(spend_bundle, now, MAX_BLOCK_COST_CLVM)
+    additions, removals = coin_store.update_coin_store_for_spend_bundle(
+        spend_bundle, now, MAX_BLOCK_COST_CLVM, COST_PER_BYTE
+    )
     now.seconds += 500
     now.height += 1
     change_count = SINGLETON_WALLET.update_state(PUZZLE_DB, removals)
@@ -688,7 +701,9 @@ def test_lifecycle_with_coinstore_as_wallet():
         )
         spend_bundle = SpendBundle([coin_spend, p2_singleton_coin_spend], G2Element())
 
-        additions, removals = coin_store.update_coin_store_for_spend_bundle(spend_bundle, now, MAX_BLOCK_COST_CLVM)
+        additions, removals = coin_store.update_coin_store_for_spend_bundle(
+            spend_bundle, now, MAX_BLOCK_COST_CLVM, COST_PER_BYTE
+        )
         now.seconds += 500
         now.height += 1
 
@@ -716,7 +731,9 @@ def test_lifecycle_with_coinstore_as_wallet():
     PUZZLE_DB.add_puzzle(full_puzzle)
 
     try:
-        additions, removals = coin_store.update_coin_store_for_spend_bundle(spend_bundle, now, MAX_BLOCK_COST_CLVM)
+        additions, removals = coin_store.update_coin_store_for_spend_bundle(
+            spend_bundle, now, MAX_BLOCK_COST_CLVM, COST_PER_BYTE
+        )
         assert 0
     except BadSpendBundleError as ex:
         assert ex.args[0] == "condition validation failure Err.ASSERT_HEIGHT_RELATIVE_FAILED"
@@ -724,7 +741,9 @@ def test_lifecycle_with_coinstore_as_wallet():
     now.seconds += 350000
     now.height += 1445
 
-    additions, removals = coin_store.update_coin_store_for_spend_bundle(spend_bundle, now, MAX_BLOCK_COST_CLVM)
+    additions, removals = coin_store.update_coin_store_for_spend_bundle(
+        spend_bundle, now, MAX_BLOCK_COST_CLVM, COST_PER_BYTE
+    )
 
     SINGLETON_WALLET.update_state(PUZZLE_DB, removals)
 
@@ -739,7 +758,9 @@ def test_lifecycle_with_coinstore_as_wallet():
     spend_bundle = SpendBundle([coin_spend], G2Element())
     spend_bundle.debug()
 
-    additions, removals = coin_store.update_coin_store_for_spend_bundle(spend_bundle, now, MAX_BLOCK_COST_CLVM)
+    additions, removals = coin_store.update_coin_store_for_spend_bundle(
+        spend_bundle, now, MAX_BLOCK_COST_CLVM, COST_PER_BYTE
+    )
     update_count = SINGLETON_WALLET.update_state(PUZZLE_DB, removals)
 
     assert update_count == 0
